@@ -34,4 +34,4 @@ Example usage:
 
 """
 
-from .csv_funcs import *
+from .csv import *
\ No newline at end of file
